==> tencentcloud-sdk-java-3.1.1000-sources.jar: com/tencentcloudapi/emr/v20190103/models/DescribeAutoScaleStrategiesResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.emr.v20190103.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeAutoScaleStrategiesResponse extends AbstractModel {

    /**
    * 按时间伸缩规则
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("TimeBasedAutoScaleStrategies")
    @Expose
    private TimeAutoScaleStrategy [] TimeBasedAutoScaleStrategies;

    /**
    * 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 按时间伸缩规则
注意：此字段可能返回 null，表示取不到有效值。 
     * @return TimeBasedAutoScaleStrategies 按时间伸缩规则
注意：此字段可能返回 null，表示取不到有效值。
     */
    public TimeAutoScaleStrategy [] getTimeBasedAutoScaleStrategies() {
        return this.TimeBasedAutoScaleStrategies;
    }

    /**
     * Set 按时间伸缩规则
注意：此字段可能返回 null，表示取不到有效值。
     * @param TimeBasedAutoScaleStrategies 按时间伸缩规则
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setTimeBasedAutoScaleStrategies(TimeAutoScaleStrategy [] TimeBasedAutoScaleStrategies) {
        this.TimeBasedAutoScaleStrategies = TimeBasedAutoScaleStrategies;
    }

    /**
     * Get 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public DescribeAutoScaleStrategiesResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeAutoScaleStrategiesResponse(DescribeAutoScaleStrategiesResponse source) {
        if (source.TimeBasedAutoScaleStrategies != null) {
            this.TimeBasedAutoScaleStrategies = new TimeAutoScaleStrategy[source.TimeBasedAutoScaleStrategies.length];
            for (int i = 0; i < source.TimeBasedAutoScaleStrategies.length; i++) {
                this.TimeBasedAutoScaleStrategies[i] = new TimeAutoScaleStrategy(source.TimeBasedAutoScaleStrategies[i]);
            }
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "TimeBasedAutoScaleStrategies.", this.TimeBasedAutoScaleStrategies);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}

==> tencentcloud-sdk-java-3.1.1130-sources.jar: com/tencentcloudapi/emr/v20190103/models/DescribeAutoScaleStrategiesResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.emr.v20190103.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeAutoScaleStrategiesResponse extends AbstractModel {

    /**
    * 按负载伸缩规则
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("LoadAutoScaleStrategies")
    @Expose
    private LoadAutoScaleStrategy [] LoadAutoScaleStrategies;

    /**
    * 按时间伸缩规则
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("TimeBasedAutoScaleStrategies")
    @Expose
    private TimeAutoScaleStrategy [] TimeBasedAutoScaleStrategies;

    /**
    * 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 按负载伸缩规则
注意：此字段可能返回 null，表示取不到有效值。 
     * @return LoadAutoScaleStrategies 按负载伸缩规则
注意：此字段可能返回 null，表示取不到有效值。
     */
    public LoadAutoScaleStrategy [] getLoadAutoScaleStrategies() {
        return this.LoadAutoScaleStrategies;
    }

    /**
     * Set 按负载伸缩规则
注意：此字段可能返回 null，表示取不到有效值。
     * @param LoadAutoScaleStrategies 按负载伸缩规则
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setLoadAutoScaleStrategies(LoadAutoScaleStrategy [] LoadAutoScaleStrategies) {
        this.LoadAutoScaleStrategies = LoadAutoScaleStrategies;
    }

    /**
     * Get 按时间伸缩规则
注意：此字段可能返回 null，表示取不到有效值。 
     * @return TimeBasedAutoScaleStrategies 按时间伸缩规则
注意：此字段可能返回 null，表示取不到有效值。
     */
    public TimeAutoScaleStrategy [] getTimeBasedAutoScaleStrategies() {
        return this.TimeBasedAutoScaleStrategies;
    }

    /**
     * Set 按时间伸缩规则
注意：此字段可能返回 null，表示取不到有效值。
     * @param TimeBasedAutoScaleStrategies 按时间伸缩规则
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setTimeBasedAutoScaleStrategies(TimeAutoScaleStrategy [] TimeBasedAutoScaleStrategies) {
        this.TimeBasedAutoScaleStrategies = TimeBasedAutoScaleStrategies;
    }

    /**
     * Get 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public DescribeAutoScaleStrategiesResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeAutoScaleStrategiesResponse(DescribeAutoScaleStrategiesResponse source) {
        if (source.LoadAutoScaleStrategies != null) {
            this.LoadAutoScaleStrategies = new LoadAutoScaleStrategy[source.LoadAutoScaleStrategies.length];
            for (int i = 0; i < source.LoadAutoScaleStrategies.length; i++) {
                this.LoadAutoScaleStrategies[i] = new LoadAutoScaleStrategy(source.LoadAutoScaleStrategies[i]);
            }
        }
        if (source.TimeBasedAutoScaleStrategies != null) {
            this.TimeBasedAutoScaleStrategies = new TimeAutoScaleStrategy[source.TimeBasedAutoScaleStrategies.length];
            for (int i = 0; i < source.TimeBasedAutoScaleStrategies.length; i++) {
                this.TimeBasedAutoScaleStrategies[i] = new TimeAutoScaleStrategy(source.TimeBasedAutoScaleStrategies[i]);
            }
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "LoadAutoScaleStrategies.", this.LoadAutoScaleStrategies);
        this.setParamArrayObj(map, prefix + "TimeBasedAutoScaleStrategies.", this.TimeBasedAutoScaleStrategies);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}
